@@ -11,6 +11,7 @@
 #![allow(clippy::missing_safety_doc)]
 
 pub mod address;
+pub mod batchmerkleproof;
 pub mod block_header;
 pub mod box_builder;
 pub mod box_selector;
@@ -30,7 +31,6 @@ mod json;
 pub mod merkleproof;
 pub mod nipopow;
 pub mod reduced;
-pub mod rest;
 pub mod secret_key;
 pub mod token;
 pub mod transaction;
@@ -39,3 +39,5 @@ pub mod util;
 pub mod wallet;
 pub use crate::error::*;
 mod error;
+#[cfg(feature = "rest")]
+pub mod rest;
